@@ -20,11 +20,13 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     void login(const QString &username, const QString &password);
     inline bool loginSupported() const { return true; }
     inline bool recaptchaRequired() const { return true; }
     inline QString recaptchaKey() const { return QString("6Lftl70SAAAAAItWJueKIVvyG0QfLgmAgzKgTbDT"); }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -41,11 +43,15 @@ private slots:
     void downloadCaptcha();
     void onWaitFinished();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QUrl m_url;
     QString m_did;
     QTimer *m_waitTimer;
     int m_waitTime;
+    int m_connections;
 };
 
 #endif // FREAKSHARE_H
